#!/usr/bin/perl
#
# Authen::PluggableCaptcha::Render::Image
#
######################################################

use strict;

package Authen::PluggableCaptcha::Render::Image;
use vars qw(@ISA $VERSION);
$VERSION= '0.01';
use Authen::PluggableCaptcha::Render ();
our @ISA= qw( Authen::PluggableCaptcha::Render );

######################################################


###
1;